
%global _hardened_build 1
%global __python %{__python3}

%global released 1

Name:           lirc
Version:        0.10.0
Release:    2%{?dist}
Summary:        The Linux Infrared Remote Control package

%global repo    http://downloads.sourceforge.net/lirc/LIRC/%{version}
%global tarball %{name}-%{version}%{?tag:-}%{?tag}.tar.gz

License:        GPLv2 and BSD
URL:            http://www.lirc.org/
Source0:        %{?released:%{repo}%{?tag:-}%{?tag}/}%{tarball}
Source1:        README.fedora
Source2:        99-remote-control-lirc.rules
Patch1:         0001-build-install-media-lirc.h-BTS-872074.patch
Patch2:         0002-lirc-setup-Fix-crash-on-start-on-missing-lirc.config.patch
Patch3:         0003-plugins-devinput-fix-glob-no-match-error.patch
Patch5:         0005-mode2-Fix-inconsistent-loglevel-debug-option-307.patch
Patch6:         0006-python-pkg-Don-t-use-deprecated-time.clock-RHBZ-1718.patch
Patch7:         0001-Replace-the-obsolete-get_event_loop-with-get_running.patch
Patch8:         0007-database.py-Handle-new-PyYAML-interface.patch


BuildRequires:  gcc-c++
BuildRequires:  /usr/bin/xsltproc
BuildRequires:  alsa-lib-devel
Buildrequires:  autoconf
BuildRequires:  automake
BuildRequires:  checkpolicy
BuildRequires:  doxygen
BuildRequires:  expect
BuildRequires:  kernel-headers
BuildRequires:  man2html-core
BuildRequires:  libftdi-devel
BuildRequires:  libtool
BuildRequires:  libusb-compat-0.1-devel
BuildRequires:  libusb1-devel

BuildRequires:  libxslt
BuildRequires:  libXt-devel
BuildRequires:  portaudio-devel
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-PyYAML
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  socat
BuildRequires:  systemd-devel
BuildRequires: make

Requires:       %{name}-libs = %{version}-%{release}
Requires:       lockdev
Suggests:       xorg-x11-misc-fonts

Requires(pre):     shadow-utils
Requires(post):    systemd
Requires(post):    systemd-sysv
Requires(post):    policycoreutils
Requires(postun):  systemd
Requires(postun):  policycoreutils
Requires(preun):   systemd

%description
LIRC is a package that allows you to decode and send infra-red and
other signals of many (but not all) commonly used remote controls.
Included applications include daemons which decode the received
signals as well as user space applications which allow controlling a
computer with a remote control.

Installing this package will install most of the LIRC sub-packages.
You might want to install lirc-core, possibly adding some other
packages to get a smaller installation.


%package        core
Summary:        LIRC core, always needed to run LIRC
Requires:       lirc-libs = %{version}-%{release}
%{?systemd_requires}

%description    core
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

The lirc core contains the lircd daemons, the devinput and
default driver and most of the applications.

%package        compat
Summary:        Compatibility package installing all lirc packages
Provides:       lirc = %{version}-%{release}
Requires:       lirc-core = %{version}-%{release}
Requires:       lirc-config = %{version}-%{release}
Requires:       lirc-tools-gui = %{version}-%{release}
Requires:       lirc-drv-portaudio = %{version}-%{release}
Requires:       lirc-drv-ftdi = %{version}-%{release}

%description    compat
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

Installing this package will install most lirc sub-packages, roughly
the same as installing previous versions of the lirc package.

%package        libs
Summary:        LIRC libraries

%description    libs
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package includes shared libraries that applications use to
interface with LIRC.


%package        config
Summary:        LIRC Configuration Tools and Data
Requires:       lirc-core = %{version}-%{release}
Requires:       lirc-doc = %{version}-%{release}
Requires:       gnome-icon-theme
Requires:       python%{python3_pkgversion}-PyYAML
BuildArch:      noarch

%description    config
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

The  config package contains tools and data to support the
LIRC configuration process.


%package        devel
Summary:        Development files for LIRC
Requires:       lirc-core = %{version}-%{release}

%description    devel
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package includes files for developing applications that use lirc
including headers and pkg-config files.


%package        doc
Summary:        LIRC documentation
BuildArch:      noarch

%description    doc
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package contains lirc documentation.


%package        disable-kernel-rc
Summary:        Disable kernel ir device handling in favor of lirc
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description  disable-kernel-rc
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package contains an udev rule which disables the kernel built-in
handling of infrared devices (i. e., rc* ones) by making lirc the only
used protocol.


%package        tools-gui
Summary:        LIRC GUI tools
Requires:       lirc-core = %{version}-%{release}

%description   tools-gui
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package contains some seldom used X11-based tools for debugging
lirc configurations.


%package        drv-portaudio
Summary:        Portaudio LIRC User-Space Driver
Requires:       lirc-core = %{version}-%{release}
License:        LGPLv2

%description    drv-portaudio
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package contains a lirc user space driver which supports
an IR receiver in microphone input using the portaudio library.


%package        drv-ftdi
Summary:        Ftdi LIRC User-Space Driver
Requires:       lirc-core = %{version}-%{release}

%description    drv-ftdi
Part of the LIRC package suite which handles IR remotes. See
the package lirc for more.

This package contains a user-space driver which works together
with the kernel, providing full support for the ftdi device.
See http://www.ftdichip.com.


%global __provides_exclude_from ^%{_docdir}/.*$
%global __requires_exclude_from ^%{_docdir}/.*$


%prep
%autosetup -p1 -n %{name}-%{version}%{?tag:-}%{?tag}
sed -i -e 's/#effective-user/effective-user /' lirc_options.conf
sed -i -e '/^effective-user/s/=$/= lirc/' lirc_options.conf
sed -i '/User=/s/; *//' systemd/lircd.service
sed -i '/Group=/s/; *//' systemd/lircd.service
sed -i 's/; *user=/User=/' systemd/irexec.service
sed -i 's/; *group=/Group=/' systemd/irexec.service

sed -i -e "s|/usr/local/etc/|%{_sysconfdir}/|" contrib/irman2lirc


%build
autoreconf -fi
export PYTHON=/usr/bin/python3

%configure \
        --docdir="%{_pkgdocdir}" \
        --enable-uinput \
        --enable-devinput \
        --with-lockdir=/var/lock/lockdev
make LANG=C.utf8 V=0 %{?_smp_mflags}

%check
if test -d python-pkg/tests; then
    cd python-pkg/tests; python3 -m unittest discover || exit 1
    cd $OLDPWD
fi

echo "Plugins: 40" > summary.ok
echo "Drivers: 51" >> summary.ok
echo "Errors: 0"   >> summary.ok
tools/lirc-lsplugins -U plugins/.libs -s > summary
diff -w summary summary.ok || exit 1


%install
make -s V=0 LIBTOOLFLAGS="--silent %{?Wnone}" DESTDIR=%{buildroot} install

chmod 755 %{buildroot}%{_datadir}/lirc/contrib/irman2lirc
find %{buildroot}%{_libdir}/ -name \*.la -delete

install -pm 755 contrib/irman2lirc %{buildroot}%{_bindir}
install -Dpm 644 doc/lirc.hwdb %{buildroot}%{_datadir}/lirc/lirc.hwdb
install -Dpm 644 contrib/60-lirc.rules \
    %{buildroot}%{_udevrulesdir}/60-lirc.rules
install -Dpm 644 %{SOURCE2} \
    %{buildroot}%{_udevrulesdir}/99-remote-control-lirc.rules
cp -a %{SOURCE1} README.fedora

mkdir -p %{buildroot}/%{_tmpfilesdir}
echo "d %{_rundir}/lirc  0755  lirc  lirc  -" \
    > %{buildroot}%{_tmpfilesdir}/lirc.conf


%pre core
getent group lirc >/dev/null || groupadd -r lirc
getent passwd lirc >/dev/null || \
    useradd -r -g lirc -d /var/log/lirc -s /sbin/nologin \
        -c "LIRC daemon user, runs lircd." lirc
usermod -a -G dialout lirc &> /dev/null || :
usermod -a -G lock lirc &> /dev/null || :
usermod -a -G input lirc &> /dev/null || :
exit 0

%post core
%systemd_post lircd.service lircmd.service
systemd-tmpfiles --create %{_tmpfilesdir}/lirc.conf

%preun core
%systemd_preun lircd.service lircmd.service

%postun core
%systemd_postun_with_restart lircd.service lircmd.service



%files compat

%files drv-portaudio
%{_libdir}/lirc/plugins/audio.so
%{_datadir}/lirc/configs/audio.conf

%files drv-ftdi
%{_libdir}/lirc/plugins/ftdi.so
%{_datadir}/lirc/configs/ftdi.conf

%files tools-gui
%{_bindir}/xmode2
%{_bindir}/irxevent
%{_mandir}/man1/irxevent*
%{_mandir}/man1/xmode2*

%files config
%{_bindir}/irdb-get
%{_bindir}/lirc-config-tool
%{_bindir}/lirc-setup
%{_mandir}/man1/irdb-get*
%{_mandir}/man1/lirc-config-tool*
%{_mandir}/man1/lirc-setup*
%{_datadir}/lirc/configs/*
%exclude %{_datadir}/lirc/configs/ftdi.conf
%exclude %{_datadir}/lirc/configs/audio.conf


%files core
%doc README AUTHORS NEWS README.fedora
%dir  %{_sysconfdir}/lirc
%{_sysconfdir}/lirc/lircd.conf.d
%config(noreplace) %{_sysconfdir}/lirc/lirc*.conf
%config(noreplace) %{_sysconfdir}/lirc/irexec.lircrc
%{_tmpfilesdir}/lirc.conf
%{_unitdir}/lirc*
%{_unitdir}/irexec.service
%{_udevrulesdir}/60-lirc.rules
%{_bindir}/*ir*
%{_bindir}/*mode2
%exclude %{_bindir}/irdb-get
%exclude %{_bindir}/xmode2
%exclude %{_bindir}/irxevent
%exclude %{_bindir}/lirc-setup
%exclude %{_bindir}/lirc-config-tool
%{_sbindir}/lirc*
%{_libdir}/lirc/plugins
%exclude %{_libdir}/lirc/plugins/ftdi.so
%exclude %{_libdir}/lirc/plugins/audio.so
%{_libdir}/python%{python3_version}/site-packages/lirc
%{_libdir}/python%{python3_version}/site-packages/lirc-setup
%{_datadir}/lirc/
/var/lib/lirc/images
/var/lib/lirc/plugins
%exclude %{_datadir}/lirc/configs/*
%{_mandir}/man1/*ir*.1*
%{_mandir}/man1/*mode2*.1*
%{_mandir}/man5/lircd.conf.*
%{_mandir}/man5/lircrc.*
%{_mandir}/man8/lirc*d.8*
%{_mandir}/man8/lircd-setup.8*
%{_mandir}/man8/lircd-uinput.8*
%exclude %{_mandir}/man1/lirc-config-tool*
%exclude %{_mandir}/man1/irdb-get*
%exclude %{_mandir}/man1/lirc-setup*
%exclude %{_mandir}/man1/irxevent*
%exclude %{_mandir}/man1/xmode2*

%files libs
%license COPYING COPYING.ciniparser COPYING.curl
%{_libdir}/libirrecord.so.*
%{_libdir}/liblirc_client.so.*
%{_libdir}/liblirc_driver.so.*
%{_libdir}/liblirc.so.*

%files devel
%{_includedir}/lirc/
%{_includedir}/lirc_private.h
%{_includedir}/lirc_driver.h
%{_includedir}/lirc_client.h
%{_libdir}/libirrecord.so
%{_libdir}/liblirc_client.so
%{_libdir}/liblirc_driver.so
%{_libdir}/liblirc.so
%{_libdir}/pkgconfig/lirc-driver.pc
%{_libdir}/pkgconfig/lirc.pc

%files doc
%license COPYING COPYING.ciniparser COPYING.curl
%doc ChangeLog
%{_pkgdocdir}

%files disable-kernel-rc
%{_udevrulesdir}/99-remote-control-lirc.rules

%changelog
* Thu May 09 2024 Fanjun Kong <fanjunkong@tencent.com> - 0.10.0-2
- epol debrand

* Mon Apr 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.10.0-1
- initial build
